%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

# Python3 support in OpenStack starts with version 3.5,
# which is only in Fedora 24+
%if 0%{?fedora} >= 24
%global with_python3 1
%endif


%global library ovsdbapp
%global module ovsdbapp

%global common_desc \
A library for writing Open vSwitch OVSDB-based applications.

%global common_desc_tests \
Python OVSDB Application Library tests. \
This package contains Python OVSDB Application Library test files.

Name:       python-%{library}
Version:    0.10.5
Release:    2%{?dist}
Summary:    Python OVSDB Application Library
License:    ASL 2.0
URL:        http://launchpad.net/%{library}/

Source0:    http://tarballs.openstack.org/%{library}/%{library}-%{upstream_version}.tar.gz

#patches_ignore=DROP-IN-RPM
#patches_base=0.10.5
Patch0001: 0001-Accept-a-Row-as-a-result-in-AddCommand.patch

BuildArch:  noarch

BuildRequires:  git
BuildRequires:  openstack-macros

%package -n python2-%{library}
Summary:    Python OVSDB Application Library
Requires:   python2-fixtures
Requires:   python-openvswitch
Requires:   python2-pbr
Requires:   python2-six
%if 0%{?fedora} > 0
Requires:   python2-netaddr
Requires:   python2-netaddr >= 0.7.18
%else
Requires:   python-netaddr >= 0.7.18
%endif
%{?python_provide:%python_provide python2-%{library}}

BuildRequires:  python2-devel
BuildRequires:  python2-pbr
BuildRequires:  python2-setuptools
BuildRequires:  python2-mock
BuildRequires:  python-openvswitch
BuildRequires:  python2-oslotest
%if 0%{?fedora} > 0
BuildRequires:  python2-netaddr >= 0.7.18
BuildRequires:  python2-testrepository
%else
BuildRequires:  python-netaddr >= 0.7.18
BuildRequires:  python-testrepository
%endif

%description -n python2-%{library}
%{common_desc}


%package -n python2-%{library}-tests
Summary:   Python OVSDB Application Library Tests
Requires:  python2-%{library} = %{version}-%{release}
Requires:  python2-mock
Requires:  python2-oslotest
%if 0%{?fedora} > 0
Requires:  python2-testrepository
%else
Requires:  python-testrepository
%endif

%description -n python2-%{library}-tests
%{common_desc_tests}

# NOTE(twilson) the project needs documentation
#%package -n python-%{library}-doc
#Summary:    Python OVSDB Application Library documentation
#
#BuildRequires: python2-sphinx
#BuildRequires: python2-oslo-sphinx
#
#%description -n python-%{library}-doc
#Python OVSDB Application Library.
#
#This package contains the documentation.

%if 0%{?with_python3}
%package -n python3-%{library}
Summary:    Python OVSDB Application Library
Requires:   python3-fixtures
Requires:   python3-netaddr >= 0.7.18
Requires:   python3-openvswitch
Requires:   python3-pbr
Requires:   python3-six
%{?python_provide:%python_provide python3-%{library}}

BuildRequires:  python3-devel
BuildRequires:  python3-pbr
BuildRequires:  python3-setuptools
BuildRequires:  python3-mock
BuildRequires:  python3-netaddr >= 0.7.18
BuildRequires:  python3-oslotest
BuildRequires:  python3-openvswitch
BuildRequires:  python3-testrepository

%description -n python3-%{library}
%{common_desc}


%package -n python3-%{library}-tests
Summary:    Python OVSDB Application Library tests
Requires:   python3-%{library} = %{version}-%{release}
Requires:   python3-mock
Requires:   python3-oslotest
Requires:   python3-testrepository

%description -n python3-%{library}-tests
%{common_desc_tests}

%endif # with_python3


%description
%{common_desc}


%prep
%autosetup -n %{library}-%{upstream_version} -S git

# Let's handle dependencies ourselves
%py_req_cleanup

%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif

# generate html docs
#%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
#rm -rf html/.{doctrees,buildinfo}

%install
%py2_install
%if 0%{?with_python3}
%py3_install
%endif

%check
%if 0%{?with_python3}
OS_TEST_PATH=./ovsdbapp/tests/unit %{__python3} setup.py test
rm -rf .testrepository
%endif
OS_TEST_PATH=./ovsdbapp/tests/unit %{__python2} setup.py test

%files -n python2-%{library}
%license LICENSE
%{python2_sitelib}/%{module}
%{python2_sitelib}/%{module}-*.egg-info
%exclude %{python2_sitelib}/%{module}/tests

%files -n python2-%{library}-tests
%{python2_sitelib}/%{module}/tests

#%files -n python-%{library}-doc
#%license LICENSE
#%doc html README.rst

%if 0%{?with_python3}
%files -n python3-%{library}
%license LICENSE
%{python3_sitelib}/%{module}
%{python3_sitelib}/%{module}-*.egg-info
%exclude %{python3_sitelib}/%{module}/tests

%files -n python3-%{library}-tests
%{python3_sitelib}/%{module}/tests
%endif # with_python3

%changelog
* Mon Jun 22 2020 Rodolfo Alonso Hernandez <ralonsoh@redhat.com> 0.10.5-2
- Accept a Row as a result in AddCommand (rhbz#1847995)

* Wed Jun 03 2020 Terry Wilson <twilson@redhat.com> 0.10.5-1
- Update to 0.10.5

* Fri Jan 17 2020 Terry Wilson <twilson@redhat.com> 0.10.4-2
- Expand retry behavior to cover other python-ovs methods (rhbz#1563581)

* Tue Oct 01 2019 Terry Wilson <twilson@redhat.com> 0.10.4-1
- Update to 0.10.4 (rhbz#1546719)

* Tue Oct 01 2019 Jon Schlueter <jschluet@redhat.com> 0.10.3-3
- update Requires for netaddr (rhbz#1553268)

* Tue May 07 2019 Jakub Libosvar <libosvar@redhat.com> 0.10.3-2
- IP should be optional in lsp_set_addresses (rhbz#1707348)

* Wed Apr 03 2019 Jon Schlueter <jschluet@redhat.com> 0.10.3-1
- Update to 0.10.3 (rhbz#1695837)

* Wed Oct 17 2018 Jon Schlueter <jschluet@redhat.com> 0.10.2-1
- Update to 0.10.2 (rhbz#1640407)

* Thu May 17 2018 Miguel Angel Ajo <majopela@redhat.com> 0.10.1-1
- Update to 0.10.1 rhbz#1579300
  Improve DbListCommand operation from O(n^2) to O(n)

* Wed Mar 14 2018 RDO <dev@lists.rdoproject.org> 0.10.0-1
- Update to 0.10.0

* Sun Feb 11 2018 RDO <dev@lists.rdoproject.org> 0.9.1-1
- Update to 0.9.1

